@@ -1,7 +1,5 @@
 """This module shows a map of your home Matrix server."""
 
-from .user import User
-from .room import Room
 from .graph import SynapseGraph
 
-__version__ = "0.3"
+__version__ = "0.5.1"
